Class: TripletexRubyClient::VatReturnscommentApi
- Inherits:
-
Object
- Object
- TripletexRubyClient::VatReturnscommentApi
- Defined in:
- lib/tripletex_ruby_client/api/vat_returnscomment_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#all(opts = {}) ⇒ ListResponseVatReturnsComment
[BETA] - Get all structured comments available.
-
#all_with_http_info(opts = {}) ⇒ Array<(ListResponseVatReturnsComment, Fixnum, Hash)>
[BETA] - Get all structured comments available.
-
#initialize(api_client = ApiClient.default) ⇒ VatReturnscommentApi
constructor
A new instance of VatReturnscommentApi.
-
#query(opts = {}) ⇒ ListResponseVatReturnsVatCodeCommentDTO
[BETA] - Get all structured comments related to a given vatCode.
-
#query_with_http_info(opts = {}) ⇒ Array<(ListResponseVatReturnsVatCodeCommentDTO, Fixnum, Hash)>
[BETA] - Get all structured comments related to a given vatCode.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ VatReturnscommentApi
Returns a new instance of VatReturnscommentApi.
19 20 21 |
# File 'lib/tripletex_ruby_client/api/vat_returnscomment_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/tripletex_ruby_client/api/vat_returnscomment_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#all(opts = {}) ⇒ ListResponseVatReturnsComment
[BETA] - Get all structured comments available
30 31 32 33 |
# File 'lib/tripletex_ruby_client/api/vat_returnscomment_api.rb', line 30 def all(opts = {}) data, _status_code, _headers = all_with_http_info(opts) data end |
#all_with_http_info(opts = {}) ⇒ Array<(ListResponseVatReturnsComment, Fixnum, Hash)>
[BETA] - Get all structured comments available
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/tripletex_ruby_client/api/vat_returnscomment_api.rb', line 43 def all_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VatReturnscommentApi.all ...' end # resource path local_var_path = '/vatReturns/comment/>all' # query parameters query_params = {} query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil? query_params[:'count'] = opts[:'count'] if !opts[:'count'].nil? query_params[:'sorting'] = opts[:'sorting'] if !opts[:'sorting'].nil? query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['tokenAuthScheme'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ListResponseVatReturnsComment') if @api_client.config.debugging @api_client.config.logger.debug "API called: VatReturnscommentApi#all\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#query(opts = {}) ⇒ ListResponseVatReturnsVatCodeCommentDTO
[BETA] - Get all structured comments related to a given vatCode
86 87 88 89 |
# File 'lib/tripletex_ruby_client/api/vat_returnscomment_api.rb', line 86 def query(opts = {}) data, _status_code, _headers = query_with_http_info(opts) data end |
#query_with_http_info(opts = {}) ⇒ Array<(ListResponseVatReturnsVatCodeCommentDTO, Fixnum, Hash)>
[BETA] - Get all structured comments related to a given vatCode
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/tripletex_ruby_client/api/vat_returnscomment_api.rb', line 99 def query_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VatReturnscommentApi.query ...' end # resource path local_var_path = '/vatReturns/comment' # query parameters query_params = {} query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil? query_params[:'count'] = opts[:'count'] if !opts[:'count'].nil? query_params[:'sorting'] = opts[:'sorting'] if !opts[:'sorting'].nil? query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? # header parameters header_params = {} # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['tokenAuthScheme'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ListResponseVatReturnsVatCodeCommentDTO') if @api_client.config.debugging @api_client.config.logger.debug "API called: VatReturnscommentApi#query\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |