Method: TripletexRubyClient::WorkingHoursScheme#list_invalid_properties
- Defined in:
- lib/tripletex_ruby_client/models/working_hours_scheme.rb
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/tripletex_ruby_client/models/working_hours_scheme.rb', line 119 def list_invalid_properties invalid_properties = Array.new if @working_hours_scheme.nil? invalid_properties.push('invalid value for "working_hours_scheme", working_hours_scheme cannot be nil.') end if !@name_no.nil? && @name_no.to_s.length > 100 invalid_properties.push('invalid value for "name_no", the character length must be smaller than or equal to 100.') end if !@code.nil? && @code.to_s.length > 100 invalid_properties.push('invalid value for "code", the character length must be smaller than or equal to 100.') end invalid_properties end |